package com.proyecto.localizandroid;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

public class LocalizAndroid extends Activity {
	/* Constante donde se guardar la palabra clave */
    public static final String PASSWORD_PREF_KEY = "PALABRACLAVE";
	/* Se crean variables enteras para la eleccion del men */
    private static final int MENU_HELP = 0;
    private static final int MENU_INFO = 1;
	private static final int DIALOG_TEXT_ENTRY = 2;
    
    /* Creamos un Editor */
    private Editor editor;
    /* Creamos un TextView */
    private TextView tvVerifyCode;
    
    /* Se llama cuando la Activity es creada por primera vez */
    @Override
    public void onCreate(Bundle savedInstanceState) {
    	/* Se llama la clase padre y mostramos el contenido en main.xml */
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        /* Creamos un Button y le asociamos el id button_change */
        Button textEntry = (Button) findViewById(R.id.button_change);
        /* Damos la funcionalidad al Button cuando es pulsado */
        textEntry.setOnClickListener(new OnClickListener() {
        	public void onClick(View v) {
        		/* muestra la ventana de dialogo definido por DIALOG_TEXT_ENTRY */
                showDialog(DIALOG_TEXT_ENTRY);
                //showDialog llama al mtodo onCreateDialog(int DIALOG_TEXT_ENTRY)
            }
        });
        
        /* Asociamos al TextView el id textview_verify_code */
        tvVerifyCode = (TextView)findViewById(R.id.textview_verify_code);
        /* Gestionamos las preferencias de la contrasea en esta variable */
        SharedPreferences passwdfile = getSharedPreferences(PASSWORD_PREF_KEY, 0);
        /* Creamos un String donde guardaremos el valor de la contrasea o null si est por defecto */
        String passwd = passwdfile.getString(PASSWORD_PREF_KEY, null);
        /* Hacemos la contrasea editable */
        editor = passwdfile.edit();
        
        /* Haremos que la contrasea por defecto sea localiza */
		if(passwd == null) {
			passwd = "localiza";
			editor.putString(PASSWORD_PREF_KEY, passwd);
			editor.commit();
		}
		
		tvVerifyCode.setText(passwd);
    }
    
    /* Crea todo lo que sera el cuadro de dilogo para cambiar la palabra clave */
    protected Dialog onCreateDialog(int id) {
        switch (id) {
        case DIALOG_TEXT_ENTRY:
            LayoutInflater factory = LayoutInflater.from(this);
            final View textEntryView = factory.inflate(R.layout.alert_dialog_text_entry, null);
            return new AlertDialog.Builder(LocalizAndroid.this)
            	//El icono de alerta
                .setIcon(R.drawable.alert_dialog_icon)
                //El mensaje de alerta de cambio de contrasea
                .setTitle(R.string.alert_dialog_text_entry)
                //El cuadro de texto de entrada
                .setView(textEntryView)
                //El botn de aceptar
                .setPositiveButton(R.string.alert_dialog_ok, new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int whichButton) {
                    	EditText et = (EditText)textEntryView.findViewById(R.id.password_edit);
                    	String vcode = et.getText().toString();
                    	if(!vcode.trim().equals("")) {
	                    	editor.putString(PASSWORD_PREF_KEY, vcode);
	                    	editor.commit();
	                		
	                		tvVerifyCode.setText(vcode);
                    	}
                    }
                })
                
                //El botn de cancelar
                .setNegativeButton(R.string.alert_dialog_cancel, new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int whichButton) {
                        /* User clicked cancel so do some stuff */
                    	dialog.dismiss();
                    }
                })
                .create();
        }
        return null;
    }
    
    /* Crea las opciones de men al pulsar el botn de men del HTC */
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);

        menu.add(0, MENU_HELP, 0, R.string.menu_help).setIcon(
                android.R.drawable.ic_menu_help);
        menu.add(0, MENU_INFO, 2, R.string.menu_info).setIcon(
                android.R.drawable.ic_menu_info_details);
        return true;
    }

    /* Lo que sale al pulsar cada una de las opciones del men */
    public boolean onOptionsItemSelected(MenuItem item) {
        super.onOptionsItemSelected(item);
        switch (item.getItemId()) {
            case MENU_HELP:
            	new AlertDialog.Builder(this) 
			    .setTitle("Localizador de Android") 
			    .setMessage("Enva un SMS a tu nmero de telfono " +
			    		"con la palabra clave que t indiques y recibirs automticamente " +
			    		"un enlace a GoogleMaps indicando la posicin GPS donde " +
			    		"se encuentra tu Android!\n\nSi el mvil desde donde envas " +
			    		"el SMS no dispone de conexin a Internet, copia el enlace " +
			    		"a cualquier navegador de un PC y la ubicacin aparecer " +
			    		"de inmediato.")
			    .show();
                return true;
            case MENU_INFO:
            	new AlertDialog.Builder(this) 
			    .setTitle("Localizador de Android") 
			    .setMessage("Versin: 1.1.0\nAutor: JauPomOle \nEmail: jaupomole@gmail.com") 
			    .show();
                return true;
        }
        return false;
    }
    
}